library(fGWAS)

#select the ES13ND trail
i<-"ES13ND"
path.fgwas <- "/local/workdir/zw355/proj/gwas.new"
mydir.out <- paste(path.fgwas, i, suffix, sep="/")

filename <- paste0(i, "_genotype_file_fgwas.txt")
#loading genotype 
data.geno <- fg.load.simple(file.simple.snp=filename, options=list(verbose=TRUE))

#loading phenotype

pheno.file <- paste0(i, ".pheno_file_fgwas.csv")
time.file <- paste0(i, ".time_file_fgwas_round0.csv")
cov.file <- paste0(i, "_genotype.pca20.csv")
## it took lon time to select curve.
data.pheno <- fg.load.phenotype(file.phe.long=pheno.file, file.phe.time=time.file, file.phe.cov=cov.file, curve.type = "Logistic", options=list(verbose=TRUE), intercept=TRUE)

## round the time values
tb.time <- read.csv(time.file)
tb.time[,-1] <-round( tb.time[,-1] )
write.csv(tb.time, file="round.time.csv",quote=F, row.names=F)
# use integer time values, but it still took long time
data.pheno <- fg.load.phenotype(file.phe.long=pheno.file, file.phe.time="round.time.csv", file.phe.cov=cov.file, curve.type = "Logistic", options=list(verbose=TRUE), intercept=TRUE)

# read PCA data
tb <- read.csv("ES13ND_genotype.pca20.csv")

#check the clusters in PCA,  PCA values dont show any clusters
pdf("org.pca.pdf")
plot(tb$PC1, tb$PC2)
plot(tb$PC2, tb$PC3)
plot(tb$PC3, tb$PC4)
plot(tb$PC4, tb$PC5)
plot(tb$PC5, tb$PC6)
plot(tb$PC6, tb$PC7)
plot(tb$PC7, tb$PC8)
plot(tb$PC8, tb$PC9)
plot(tb$PC9, tb$PC10)
dev.off();

# redo PCAs using plink software
pca <- fg.get.pca(data.geno, plink.path="~/lib/plink1.9/plink")
pdf("new.pca.pdf")
plot(pca$PCA1, pca$PCA2)
plot(pca$PCA2, pca$PCA3)
plot(pca$PCA3, pca$PCA4)
plot(pca$PCA4, pca$PCA5)
plot(pca$PCA5, pca$PCA6)
plot(pca$PCA6, pca$PCA7)
plot(pca$PCA7, pca$PCA8)
plot(pca$PCA8, pca$PCA9)
plot(pca$PCA9, pca$PCA10)
dev.off()

##only select 5 PCAs to speed up
write.csv(pca[, c(1:5)], file="new.pca.csv", quote=F)

# curve fitting
data.pheno <- fg.load.phenotype(file.phe.long=pheno.file, file.phe.time="round.time.csv", file.phe.cov="new.pca.csv", curve.type = "Logistic", options=list(verbose=TRUE), intercept=TRUE)
plot(data.pheno, file.pdf="data.pheno.pdf")

# doing fGWAS within 24 hours
r.fgwas <- fg.snpscan(fgwas.gen.obj=data.geno, fgwas.phe.obj=data.pheno, method="optim-fgwas", options=list(verbose=TRUE, ncores=15, piecewise=1000, min.optim.success=1, max.optim.failure=10, use.snowfall=TRUE))
r.fwgas

# adjust p-value inflation
r.fgwas2 <- fg.adjust.inflation(r.fgwas)
r.fgwas2

save(r.fgwas2, r.fgwas, file="r.fgwas2.rdata");

# QQ plot 
fg_qqplot(r.fgwas2, "qq.r.fgwas2.png", title="r.fgwas2", width=480 )

# select significant SNPs
tb.sig <- fg.select.sigsnp(r.fgwas2)

# plot curves
plot.fgwas.curve( r.fgwas2, tb.sig$INDEX, file.pdf="r.fgwas2.curve.plot.pdf");

# plot manhattan 
plot(r.fgwas2, file.pdf="r.fgwas2.man.pdf")




